@@ -23,7 +23,7 @@ use bonsaidb_core::{
         self, Payload, Request, Response, ServerRequest, ServerResponse, CURRENT_PROTOCOL_VERSION,
     },
     permissions::Permissions,
-    schema::{NamedReference, Schema, SchemaName, Schematic},
+    schema::{Nameable, Schema, SchemaName, Schematic},
 };
 use bonsaidb_utils::fast_async_lock;
 use derive_where::derive_where;
@@ -609,15 +609,33 @@ impl<A: CustomApi> StorageConnection for Client<A> {
         }
     }
 
+    async fn delete_user<'user, U: Nameable<'user, u64> + Send + Sync>(
+        &self,
+        user: U,
+    ) -> Result<(), bonsaidb_core::Error> {
+        match self
+            .send_request(Request::Server(ServerRequest::DeleteUser {
+                user: user.name()?.into_owned(),
+            }))
+            .await?
+        {
+            Response::Ok => Ok(()),
+            Response::Error(err) => Err(err),
+            other => Err(bonsaidb_core::Error::Networking(
+                networking::Error::UnexpectedResponse(format!("{:?}", other)),
+            )),
+        }
+    }
+
     #[cfg(feature = "password-hashing")]
-    async fn set_user_password<'user, U: Into<NamedReference<'user>> + Send + Sync>(
+    async fn set_user_password<'user, U: Nameable<'user, u64> + Send + Sync>(
         &self,
         user: U,
         password: bonsaidb_core::connection::SensitiveString,
     ) -> Result<(), bonsaidb_core::Error> {
         match self
             .send_request(Request::Server(ServerRequest::SetUserPassword {
-                user: user.into().into_owned(),
+                user: user.name()?.into_owned(),
                 password,
             }))
             .await?
@@ -631,14 +649,14 @@ impl<A: CustomApi> StorageConnection for Client<A> {
     }
 
     #[cfg(feature = "password-hashing")]
-    async fn authenticate<'user, U: Into<NamedReference<'user>> + Send + Sync>(
+    async fn authenticate<'user, U: Nameable<'user, u64> + Send + Sync>(
         &self,
         user: U,
         authentication: Authentication,
     ) -> Result<Authenticated, bonsaidb_core::Error> {
         match self
             .send_request(Request::Server(ServerRequest::Authenticate {
-                user: user.into().into_owned(),
+                user: user.name()?.into_owned(),
                 authentication,
             }))
             .await?
@@ -654,8 +672,8 @@ impl<A: CustomApi> StorageConnection for Client<A> {
     async fn add_permission_group_to_user<
         'user,
         'group,
-        U: Into<NamedReference<'user>> + Send + Sync,
-        G: Into<NamedReference<'group>> + Send + Sync,
+        U: Nameable<'user, u64> + Send + Sync,
+        G: Nameable<'group, u64> + Send + Sync,
     >(
         &self,
         user: U,
@@ -664,8 +682,8 @@ impl<A: CustomApi> StorageConnection for Client<A> {
         match self
             .send_request(Request::Server(
                 ServerRequest::AlterUserPermissionGroupMembership {
-                    user: user.into().into_owned(),
-                    group: permission_group.into().into_owned(),
+                    user: user.name()?.into_owned(),
+                    group: permission_group.name()?.into_owned(),
                     should_be_member: true,
                 },
             ))
@@ -682,8 +700,8 @@ impl<A: CustomApi> StorageConnection for Client<A> {
     async fn remove_permission_group_from_user<
         'user,
         'group,
-        U: Into<NamedReference<'user>> + Send + Sync,
-        G: Into<NamedReference<'group>> + Send + Sync,
+        U: Nameable<'user, u64> + Send + Sync,
+        G: Nameable<'group, u64> + Send + Sync,
     >(
         &self,
         user: U,
@@ -692,8 +710,8 @@ impl<A: CustomApi> StorageConnection for Client<A> {
         match self
             .send_request(Request::Server(
                 ServerRequest::AlterUserPermissionGroupMembership {
-                    user: user.into().into_owned(),
-                    group: permission_group.into().into_owned(),
+                    user: user.name()?.into_owned(),
+                    group: permission_group.name()?.into_owned(),
                     should_be_member: false,
                 },
             ))
@@ -710,8 +728,8 @@ impl<A: CustomApi> StorageConnection for Client<A> {
     async fn add_role_to_user<
         'user,
         'group,
-        U: Into<NamedReference<'user>> + Send + Sync,
-        G: Into<NamedReference<'group>> + Send + Sync,
+        U: Nameable<'user, u64> + Send + Sync,
+        G: Nameable<'group, u64> + Send + Sync,
     >(
         &self,
         user: U,
@@ -719,8 +737,8 @@ impl<A: CustomApi> StorageConnection for Client<A> {
     ) -> Result<(), bonsaidb_core::Error> {
         match self
             .send_request(Request::Server(ServerRequest::AlterUserRoleMembership {
-                user: user.into().into_owned(),
-                role: role.into().into_owned(),
+                user: user.name()?.into_owned(),
+                role: role.name()?.into_owned(),
                 should_be_member: true,
             }))
             .await?
@@ -736,8 +754,8 @@ impl<A: CustomApi> StorageConnection for Client<A> {
     async fn remove_role_from_user<
         'user,
         'group,
-        U: Into<NamedReference<'user>> + Send + Sync,
-        G: Into<NamedReference<'group>> + Send + Sync,
+        U: Nameable<'user, u64> + Send + Sync,
+        G: Nameable<'group, u64> + Send + Sync,
     >(
         &self,
         user: U,
@@ -745,8 +763,8 @@ impl<A: CustomApi> StorageConnection for Client<A> {
     ) -> Result<(), bonsaidb_core::Error> {
         match self
             .send_request(Request::Server(ServerRequest::AlterUserRoleMembership {
-                user: user.into().into_owned(),
-                role: role.into().into_owned(),
+                user: user.name()?.into_owned(),
+                role: role.name()?.into_owned(),
                 should_be_member: false,
             }))
             .await?
